@@ -21,15 +21,17 @@ pub struct Trainer {
 }
 
 impl Trainer {
-	pub fn run(&self, display: bool) {
+	pub fn run(&self, full: bool, display: bool) {
 		display.then(|| display::trainer(&self));
 
 		let proc = self.probe();
 		if let Ok(proc) = proc {
 			for feature in &self.features {
-				display.then(|| display::feature(feature));
-				let res = feature.run(&proc);
-				display.then(|| display::feature_result(&feature, &res));
+				if feature.enable {
+					display.then(|| display::feature(feature));
+					let res = feature.run(&proc, full);
+					display.then(|| display::feature_result(&feature, &res, full));
+				}
 			}
 		} else if let Err(e) = proc {
 			display.then(|| display::trainer_err(&e));
